.. _collection_integration_tests:


*****************************************
Adding integration tests to a collection
*****************************************

This section describes the steps to add integration tests to a collection and how to run them locally using the ``ansible-test`` command.

.. toctree::
   :maxdepth: 1

   collection_integration_about
   collection_integration_updating
   collection_integration_running
   collection_integration_add


.. seealso::

  :ref:`testing_units_modules`
     Unit testing Ansible modules
  `pytest <https://docs.pytest.org/en/latest/>`_
     Pytest framework documentation
  :ref:`developing_testing`
     Ansible Testing Guide
  :ref:`collection_unit_tests`
     Unit testing for collections
  :ref:`testing_integration`
     Integration tests guide
  :ref:`testing_collections`
     Testing collections
  :ref:`testing_resource_modules`
     Resource module integration tests
  :ref:`collection_pr_test`
     How to test a pull request locally
